@@ -66,6 +66,21 @@ HTTP_CORS_TTL: int = environ.parseint(
 #: Path to the URL configuration file.
 HTTP_URLCONF = os.getenv('HTTP_URLCONF') or 'etc/urlconf.yml'
 
+#: For worker-based HTTP servers, the worker timeout.
+HTTP_WORKER_TIMEOUT = environ.parseint(os.environ, 'HTTP_WORKER_TIMEOUT', 180)
+
+#: An X.509 certificate used in local development.
+LOCALHOST_SSL_CRT = environ.parsefilepath(
+    os.environ,'LOCALHOST_SSL_CRT', default='pki/server/noop.crt'
+)
+
+#: A private key that is used with TLS connections in local development
+#: servers.
+LOCALHOST_SSL_KEY = environ.parsefilepath(
+    os.environ, 'LOCALHOST_SSL_KEY', default='pki/server/noop.key'
+)
+
+
 #: The default log level.
 LOG_LEVEL = os.getenv('LOG_LEVEL') or 'WARNING'
 
